==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CAPTCHAInstance.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CAPTCHAType;
import com.okta.sdk.resource.model.LinksSelf;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ CAPTCHAInstance.JSON_PROPERTY_ID, CAPTCHAInstance.JSON_PROPERTY_NAME,
        CAPTCHAInstance.JSON_PROPERTY_SECRET_KEY, CAPTCHAInstance.JSON_PROPERTY_SITE_KEY,
        CAPTCHAInstance.JSON_PROPERTY_TYPE, CAPTCHAInstance.JSON_PROPERTY_LINKS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CAPTCHAInstance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_SECRET_KEY = "secretKey";
    private String secretKey;

    public static final String JSON_PROPERTY_SITE_KEY = "siteKey";
    private String siteKey;

    public static final String JSON_PROPERTY_TYPE = "type";
    private CAPTCHAType type;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksSelf links;

    public CAPTCHAInstance() {
    }

    /*
     * @JsonCreator public CAPTCHAInstance(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id ) { this(); this.id = id; }
     */

    /**
     * The unique key for the CAPTCHA instance
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The unique key for the CAPTCHA instance")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    public CAPTCHAInstance name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of the CAPTCHA instance
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of the CAPTCHA instance")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public CAPTCHAInstance secretKey(String secretKey) {

        this.secretKey = secretKey;
        return this;
    }

    /**
     * The secret key issued from the CAPTCHA provider to perform server-side validation for a CAPTCHA token
     *
     * @return secretKey
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The secret key issued from the CAPTCHA provider to perform server-side validation for a CAPTCHA token")
    @JsonProperty(JSON_PROPERTY_SECRET_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSecretKey() {
        return secretKey;
    }

    @JsonProperty(JSON_PROPERTY_SECRET_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public CAPTCHAInstance siteKey(String siteKey) {

        this.siteKey = siteKey;
        return this;
    }

    /**
     * The site key issued from the CAPTCHA provider to render a CAPTCHA on a page
     *
     * @return siteKey
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The site key issued from the CAPTCHA provider to render a CAPTCHA on a page")
    @JsonProperty(JSON_PROPERTY_SITE_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSiteKey() {
        return siteKey;
    }

    @JsonProperty(JSON_PROPERTY_SITE_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSiteKey(String siteKey) {
        this.siteKey = siteKey;
    }

    public CAPTCHAInstance type(CAPTCHAType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CAPTCHAType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(CAPTCHAType type) {
        this.type = type;
    }

    public CAPTCHAInstance links(LinksSelf links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksSelf getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksSelf links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CAPTCHAInstance caPTCHAInstance = (CAPTCHAInstance) o;
        return Objects.equals(this.id, caPTCHAInstance.id) && Objects.equals(this.name, caPTCHAInstance.name)
                && Objects.equals(this.secretKey, caPTCHAInstance.secretKey)
                && Objects.equals(this.siteKey, caPTCHAInstance.siteKey)
                && Objects.equals(this.type, caPTCHAInstance.type) && Objects.equals(this.links, caPTCHAInstance.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, name, secretKey, siteKey, type, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CAPTCHAInstance {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    secretKey: ").append(toIndentedString(secretKey)).append("\n");
        sb.append("    siteKey: ").append(toIndentedString(siteKey)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CAPTCHAInstance.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CAPTCHAType;
import com.okta.sdk.resource.model.LinksSelf;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ CAPTCHAInstance.JSON_PROPERTY_ID, CAPTCHAInstance.JSON_PROPERTY_NAME,
        CAPTCHAInstance.JSON_PROPERTY_SECRET_KEY, CAPTCHAInstance.JSON_PROPERTY_SITE_KEY,
        CAPTCHAInstance.JSON_PROPERTY_TYPE, CAPTCHAInstance.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CAPTCHAInstance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_SECRET_KEY = "secretKey";
    private String secretKey;

    public static final String JSON_PROPERTY_SITE_KEY = "siteKey";
    private String siteKey;

    public static final String JSON_PROPERTY_TYPE = "type";
    private CAPTCHAType type;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksSelf links;

    public CAPTCHAInstance() {
    }

    /*
     * @JsonCreator public CAPTCHAInstance(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id ) { this(); this.id = id; }
     */

    /**
     * The unique key for the CAPTCHA instance
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The unique key for the CAPTCHA instance")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    public CAPTCHAInstance name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of the CAPTCHA instance
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of the CAPTCHA instance")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public CAPTCHAInstance secretKey(String secretKey) {

        this.secretKey = secretKey;
        return this;
    }

    /**
     * The secret key issued from the CAPTCHA provider to perform server-side validation for a CAPTCHA token
     *
     * @return secretKey
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The secret key issued from the CAPTCHA provider to perform server-side validation for a CAPTCHA token")
    @JsonProperty(JSON_PROPERTY_SECRET_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSecretKey() {
        return secretKey;
    }

    @JsonProperty(JSON_PROPERTY_SECRET_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public CAPTCHAInstance siteKey(String siteKey) {

        this.siteKey = siteKey;
        return this;
    }

    /**
     * The site key issued from the CAPTCHA provider to render a CAPTCHA on a page
     *
     * @return siteKey
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The site key issued from the CAPTCHA provider to render a CAPTCHA on a page")
    @JsonProperty(JSON_PROPERTY_SITE_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSiteKey() {
        return siteKey;
    }

    @JsonProperty(JSON_PROPERTY_SITE_KEY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSiteKey(String siteKey) {
        this.siteKey = siteKey;
    }

    public CAPTCHAInstance type(CAPTCHAType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CAPTCHAType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(CAPTCHAType type) {
        this.type = type;
    }

    public CAPTCHAInstance links(LinksSelf links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksSelf getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksSelf links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CAPTCHAInstance caPTCHAInstance = (CAPTCHAInstance) o;
        return Objects.equals(this.id, caPTCHAInstance.id) && Objects.equals(this.name, caPTCHAInstance.name)
                && Objects.equals(this.secretKey, caPTCHAInstance.secretKey)
                && Objects.equals(this.siteKey, caPTCHAInstance.siteKey)
                && Objects.equals(this.type, caPTCHAInstance.type) && Objects.equals(this.links, caPTCHAInstance.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, name, secretKey, siteKey, type, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CAPTCHAInstance {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    secretKey: ").append(toIndentedString(secretKey)).append("\n");
        sb.append("    siteKey: ").append(toIndentedString(siteKey)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
